"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const i18next_1 = require("i18next");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const picocolors_1 = tslib_1.__importDefault(require("picocolors"));
const path = tslib_1.__importStar(require("path"));
const integration_1 = require("../../domains/integration");
const project_name_1 = require("../../domains/project-name");
const git_repository_1 = require("../../domains/git-repository");
const directory_1 = require("../../domains/directory");
class GenerateStore extends core_1.Command {
    async run() {
        const projectName = await (0, project_name_1.getProjectName)((0, i18next_1.t)('command.generate_store.input.project_name'));
        const integration = await (0, integration_1.getIntegration)({
            message: (0, i18next_1.t)('command.generate_store.input.integration'),
            customIntegrationRepositoryMessage: (0, i18next_1.t)('command.generate_store.input.custom_integration_repository')
        });
        const projectDir = path.resolve(projectName);
        if (await (0, directory_1.existsDirectory)(projectDir)) {
            const { overwrite } = await inquirer_1.default.prompt({
                type: 'confirm',
                name: 'overwrite',
                message: () => (0, i18next_1.t)('command.generate_store.input.overwrite', { projectName })
            });
            if (!overwrite) {
                this.log((0, i18next_1.t)('command.generate_store.message.skipping'));
                this.exit(0);
            }
        }
        await (0, git_repository_1.cloneGitRepository)({
            projectDir,
            gitRepositoryURL: integration.gitRepositoryURL
        });
        await (0, git_repository_1.terminateGitRepository)(projectDir);
        this.log((0, i18next_1.t)('command.generate_store.message.success', { projectName }));
        this.log((0, i18next_1.t)('command.generate_store.message.install'));
        this.log('');
        this.log(picocolors_1.default.green((0, i18next_1.t)('command.generate_store.message.install_commands.0', { projectName })));
        this.log(picocolors_1.default.green((0, i18next_1.t)('command.generate_store.message.install_commands.1', { projectName })));
        this.log('');
        if (integration.documentationURL) {
            this.log((0, i18next_1.t)('command.generate_store.message.configure', {
                documentationURL: integration.documentationURL
            }));
        }
        this.log((0, i18next_1.t)('command.generate_store.message.start'));
        this.log('');
        this.log(picocolors_1.default.green((0, i18next_1.t)('command.generate_store.message.start_command', { projectName })));
        this.log('');
        this.log('');
        this.exit(0);
    }
}
exports.default = GenerateStore;
GenerateStore.description = (0, i18next_1.t)('command.generate_store.description');
GenerateStore.examples = ['<%= config.bin %> <%= command.id %>'];
GenerateStore.flags = {};
GenerateStore.args = [];
//# sourceMappingURL=store.js.map