"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const i18next_1 = require("i18next");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const isomorphic_git_1 = tslib_1.__importDefault(require("isomorphic-git"));
const extractSuggestionFromError_1 = tslib_1.__importDefault(require("./extractSuggestionFromError"));
const validateGitRepositoryURL_1 = tslib_1.__importDefault(require("./validateGitRepositoryURL"));
/** Gets a git repository URL from user's input. */
const getGitRepositoryURL = async (message) => {
    let suggestion = null;
    const answers = await inquirer_1.default.prompt([
        {
            type: 'input',
            name: 'gitRepositoryURL',
            message,
            validate: async (url) => {
                suggestion = null;
                const [valid, error] = await (0, validateGitRepositoryURL_1.default)(url);
                if (valid)
                    return true;
                suggestion = await (0, extractSuggestionFromError_1.default)(error);
                if (suggestion)
                    return true;
                return error instanceof isomorphic_git_1.default.Errors.UrlParseError
                    ? (0, i18next_1.t)('domain.git_repository_url.is_invalid')
                    : (0, i18next_1.t)('domain.git_repository_url.was_not_found');
            }
        },
        {
            type: 'confirm',
            name: 'acceptSuggestionAsGitRepositoryURL',
            when: () => Boolean(suggestion),
            message: () => (0, i18next_1.t)('domain.git_repository_url.suggestion', { suggestion })
        }
    ]);
    if (!suggestion)
        return answers.gitRepositoryURL;
    return answers.acceptSuggestionAsGitRepositoryURL ? suggestion : getGitRepositoryURL(message);
};
exports.default = getGitRepositoryURL;
//# sourceMappingURL=getGitRepositoryURL.js.map